@@ -8,33 +8,28 @@
 import os
 
 from pymtl3.passes.PassConfigs import BasePassConfigs, Checker
+from pymtl3.passes.PlaceholderPass import PlaceholderPass
 
 
-def expand( v ):
-  return os.path.expanduser(os.path.expandvars(v))
+def expand( path ):
+  return os.path.expanduser(os.path.expandvars(path))
 
 class PlaceholderConfigs( BasePassConfigs ):
 
   Options = {
     # Should placeholder passes handle this instance?
-    "is_valid" : True,
+    "enable" : True,
 
     # Does the module to be imported has `clk` port?
     "has_clk" : True,
 
     # Does the module to be imported has `reset` port?
     "has_reset" : True,
-
-    # Give an explicit name to the wrapper module
-    # Use {top_module}_wrapper by default
-    # "explicit_module_name" : "",
   }
 
   Checkers = {
-    ("is_valid", "has_clk", "has_reset") :
+    ("enable", "has_clk", "has_reset") :
       Checker( lambda v: isinstance(v, bool), "expects a boolean" ),
-
-    # "explicit_module_name": Checker( lambda v: isinstance(v, str), "expects a string" ),
   }
 
-  PassName = 'PlaceholderConfigs'
+  Pass = PlaceholderPass
